# PySentry - pip-audit Benchmark Report

**Generated:** 2025-10-01 17:03:50
**Duration:** 1m 58.52s
**Total Tests:** 20

## Executive Summary

**Overall Success Rate:** 100.0% (20/20 successful runs)

### Small_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.251s) - 35.82x faster than slowest
- **Memory Efficient:** pysentry-osv (9.73 MB) - 8.91x less memory than highest

### Small_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.225s) - 35.73x faster than slowest
- **Memory Efficient:** pysentry-osv (9.61 MB) - 9.75x less memory than highest

### Large_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.725s) - 27.37x faster than slowest
- **Memory Efficient:** pysentry-osv (10.55 MB) - 8.94x less memory than highest

### Large_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.710s) - 22.73x faster than slowest
- **Memory Efficient:** pysentry-osv (9.75 MB) - 8.22x less memory than highest

## Test Environment

- **Platform:** Linux-6.11.0-1018-azure-x86_64-with-glibc2.39
- **Python Version:** 3.11.13
- **CPU Cores:** 4
- **Total Memory:** 15.62 GB
- **Available Memory:** 14.68 GB

## Performance Comparison

### Small_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.251s | 1.00x |
| 🥈 pysentry-osv | 0.800s | 3.18x |
|  pysentry-all-sources | 1.105s | 4.40x |
|  pysentry-pypa | 1.344s | 5.35x |
|  pip-audit-default | 8.995s | 35.82x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 9.73 MB | 1.00x |
| 🥈 pysentry-pypi | 10.30 MB | 1.06x |
|  pip-audit-default | 45.71 MB | 4.70x |
|  pysentry-pypa | 60.87 MB | 6.26x |
|  pysentry-all-sources | 86.62 MB | 8.91x |

### Small_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.225s | 1.00x |
| 🥈 pysentry-pypa | 0.693s | 3.08x |
|  pysentry-osv | 0.781s | 3.47x |
|  pysentry-all-sources | 0.819s | 3.64x |
|  pip-audit-default | 8.033s | 35.73x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 9.61 MB | 1.00x |
| 🥈 pysentry-pypi | 10.67 MB | 1.11x |
|  pysentry-pypa | 43.20 MB | 4.49x |
|  pip-audit-default | 44.82 MB | 4.66x |
|  pysentry-all-sources | 93.77 MB | 9.75x |

### Large_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.725s | 1.00x |
| 🥈 pysentry-pypa | 1.522s | 2.10x |
|  pysentry-osv | 3.638s | 5.02x |
|  pysentry-all-sources | 4.179s | 5.76x |
|  pip-audit-default | 19.837s | 27.37x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 10.55 MB | 1.00x |
| 🥈 pysentry-pypi | 12.95 MB | 1.23x |
|  pip-audit-default | 53.12 MB | 5.03x |
|  pysentry-pypa | 61.15 MB | 5.80x |
|  pysentry-all-sources | 94.30 MB | 8.94x |

### Large_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.710s | 1.00x |
| 🥈 pysentry-pypa | 1.130s | 1.59x |
|  pysentry-osv | 3.954s | 5.57x |
|  pysentry-all-sources | 4.199s | 5.91x |
|  pip-audit-default | 16.134s | 22.73x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 9.75 MB | 1.00x |
| 🥈 pysentry-pypi | 12.74 MB | 1.31x |
|  pip-audit-default | 47.41 MB | 4.86x |
|  pysentry-pypa | 60.06 MB | 6.16x |
|  pysentry-all-sources | 80.21 MB | 8.22x |

## Detailed Analysis

### Pysentry Performance

- **Execution Time:** Avg: 1.630s, Min: 0.225s, Max: 4.199s

- **Memory Usage:** Avg: 41.65 MB, Min: 9.61 MB, Max: 94.30 MB

- **Success Rate:** 100.0% (16/16)

### Pip-Audit Performance

- **Execution Time:** Avg: 13.250s, Min: 8.033s, Max: 19.837s

- **Memory Usage:** Avg: 47.77 MB, Min: 44.82 MB, Max: 53.12 MB

- **Success Rate:** 100.0% (4/4)